<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#		  DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['Manage every blog configuration directive'] = '';
$GLOBALS['__l10n']['Akismet interface for Dotclear'] = '';
$GLOBALS['__l10n']['Generic antispam plugin for Dotclear'] = '';
$GLOBALS['__l10n']['Manage post attachments'] = '';
$GLOBALS['__l10n']['Manage your blogroll'] = '';
$GLOBALS['__l10n']['Configure your Blowup Theme'] = '';
$GLOBALS['__l10n']['Legacy modules for dotclear'] = '';
$GLOBALS['__l10n']['Trackback validity check'] = '';
$GLOBALS['__l10n']['Import and Export your blog'] = '';
$GLOBALS['__l10n']['Maintain your installation'] = '';
$GLOBALS['__l10n']['Serve entries as simple web pages'] = '';
$GLOBALS['__l10n']['Ping services'] = '';
$GLOBALS['__l10n']['Simple menu for Dotclear'] = '';
$GLOBALS['__l10n']['Tags for posts'] = '';
$GLOBALS['__l10n']['Theme Editor'] = '';
$GLOBALS['__l10n']['Manage every user preference directive'] = '';
$GLOBALS['__l10n']['Widgets for your blog sidebars'] = '';
$GLOBALS['__l10n']['Search engine form'] = '';
$GLOBALS['__l10n']['List of navigation links'] = '';
$GLOBALS['__l10n']['List of selected entries'] = '';
$GLOBALS['__l10n']['List of available languages'] = '';
$GLOBALS['__l10n']['List of categories'] = '';
$GLOBALS['__l10n']['Feed subscription links (RSS or Atom)'] = '';
$GLOBALS['__l10n']['List of last entries from feed (RSS or Atom)'] = '';
$GLOBALS['__l10n']['Simple text'] = '';
$GLOBALS['__l10n']['List of last entries published'] = '';
$GLOBALS['__l10n']['List of last comments published'] = '';
$GLOBALS['__l10n']['Tags cloud'] = '';
$GLOBALS['__l10n']['List of published pages'] = '';
$GLOBALS['__l10n']['Blogroll list'] = '';
$GLOBALS['__l10n']['List of simple menu items'] = '';
$GLOBALS['__l10n']['Configuration successfully updated'] = '';
$GLOBALS['__l10n']['no'] = '';
$GLOBALS['__l10n']['yes'] = '';
$GLOBALS['__l10n']['about:config'] = '';
$GLOBALS['__l10n']['Settings for %s'] = '';
$GLOBALS['__l10n']['Value'] = '';
$GLOBALS['__l10n']['Description'] = '';
$GLOBALS['__l10n']['Goto:'] = '';
$GLOBALS['__l10n']['Global settings'] = '';
$GLOBALS['__l10n']['Akismet spam filter'] = '';
$GLOBALS['__l10n']['Filtered by %s.'] = '';
$GLOBALS['__l10n']['Filter configuration have been successfully saved.'] = '';
$GLOBALS['__l10n']['Akismet API key:'] = '';
$GLOBALS['__l10n']['API key verified'] = '';
$GLOBALS['__l10n']['API key not verified'] = '';
$GLOBALS['__l10n']['Get your own API key'] = '';
$GLOBALS['__l10n']['Antispam'] = '';
$GLOBALS['__l10n']['All spam comments older than %s day(s) will be automatically deleted.'] = '';
$GLOBALS['__l10n']['You can modify this duration in the %s'] = '';
$GLOBALS['__l10n']['Delete junk comments older than'] = '';
$GLOBALS['__l10n']['days'] = '';
$GLOBALS['__l10n']['Set spam filters.'] = '';
$GLOBALS['__l10n']['IP Blacklist / Whitelist Filter'] = '';
$GLOBALS['__l10n']['Filtered by %1$s with rule %2$s.'] = '';
$GLOBALS['__l10n']['IP address has been successfully added.'] = '';
$GLOBALS['__l10n']['IP addresses have been successfully removed.'] = '';
$GLOBALS['__l10n']['Blacklist'] = '';
$GLOBALS['__l10n']['Whitelist'] = '';
$GLOBALS['__l10n']['Add an IP address: '] = '';
$GLOBALS['__l10n']['Global IP (used for all blogs)'] = '';
$GLOBALS['__l10n']['Add'] = '';
$GLOBALS['__l10n']['No IP address in list.'] = '';
$GLOBALS['__l10n']['IP list'] = '';
$GLOBALS['__l10n']['Local IPs (used only for this blog)'] = '';
$GLOBALS['__l10n']['Global IPs (used for all blogs)'] = '';
$GLOBALS['__l10n']['Checks sender IP address against DNSBL servers'] = '';
$GLOBALS['__l10n']['Filtered by %1$s with server %2$s.'] = '';
$GLOBALS['__l10n']['The list of DNSBL servers has been succesfully updated.'] = '';
$GLOBALS['__l10n']['IP Lookup servers'] = '';
$GLOBALS['__l10n']['Add here a coma separated list of servers.'] = '';
$GLOBALS['__l10n']['Checks links in comments against surbl.org'] = '';
$GLOBALS['__l10n']['Words Blacklist'] = '';
$GLOBALS['__l10n']['Filtered by %1$s with word %2$s.'] = '';
$GLOBALS['__l10n']['Words have been successfully added.'] = '';
$GLOBALS['__l10n']['Word has been successfully added.'] = '';
$GLOBALS['__l10n']['Words have been successfully removed.'] = '';
$GLOBALS['__l10n']['Add a word '] = '';
$GLOBALS['__l10n']['Global word (used for all blogs)'] = '';
$GLOBALS['__l10n']['No word in list.'] = '';
$GLOBALS['__l10n']['List of bad words'] = '';
$GLOBALS['__l10n']['Local words (used only for this blog)'] = '';
$GLOBALS['__l10n']['Global words (used for all blogs)'] = '';
$GLOBALS['__l10n']['Delete selected words'] = '';
$GLOBALS['__l10n']['Create default wordlist'] = '';
$GLOBALS['__l10n']['This word exists'] = '';
$GLOBALS['__l10n']['No description'] = '';
$GLOBALS['__l10n']['Filtered by %1$s (%2$s)'] = '';
$GLOBALS['__l10n']['Unknown filter.'] = '';
$GLOBALS['__l10n']['This comment is a spam:'] = '';
$GLOBALS['__l10n']['(including %d spam comment)'] = '';
$GLOBALS['__l10n']['(including %d spam comments)'] = '';
$GLOBALS['__l10n']['Spam moderation'] = '';
$GLOBALS['__l10n']['Spam'] = '';
$GLOBALS['__l10n']['Ham'] = '';
$GLOBALS['__l10n']['Filter does not exist.'] = '';
$GLOBALS['__l10n']['Filter has no user interface.'] = '';
$GLOBALS['__l10n']['Filters configuration has been successfully saved.'] = '';
$GLOBALS['__l10n']['%s configuration'] = '';
$GLOBALS['__l10n']['%s filter configuration'] = '';
$GLOBALS['__l10n']['Back to filters list'] = '';
$GLOBALS['__l10n']['Information'] = '';
$GLOBALS['__l10n']['Junk comments:'] = '';
$GLOBALS['__l10n']['Published comments:'] = '';
$GLOBALS['__l10n']['Available spam filters'] = '';
$GLOBALS['__l10n']['Order'] = '';
$GLOBALS['__l10n']['Active'] = '';
$GLOBALS['__l10n']['Auto Del.'] = '';
$GLOBALS['__l10n']['Filter name'] = '';
$GLOBALS['__l10n']['Filter configuration'] = '';
$GLOBALS['__l10n']['position'] = '';
$GLOBALS['__l10n']['Syndication'] = '';
$GLOBALS['__l10n']['Junk comments RSS feed'] = '';
$GLOBALS['__l10n']['Published comments RSS feed'] = '';
$GLOBALS['__l10n']['Attachments'] = '';
$GLOBALS['__l10n']['Attachments (%d)'] = '';
$GLOBALS['__l10n']['remove'] = '';
$GLOBALS['__l10n']['No attachment.'] = '';
$GLOBALS['__l10n']['Add files to this entry'] = '';
$GLOBALS['__l10n']['Blogroll'] = '';
$GLOBALS['__l10n']['manage blogroll'] = '';
$GLOBALS['__l10n']['Links'] = '';
$GLOBALS['__l10n']['Title (optional)'] = '';
$GLOBALS['__l10n']['All categories'] = '';
$GLOBALS['__l10n']['Display on:'] = '';
$GLOBALS['__l10n']['All pages'] = '';
$GLOBALS['__l10n']['Home page only'] = '';
$GLOBALS['__l10n']['Except on home page'] = '';
$GLOBALS['__l10n']['Content only'] = '';
$GLOBALS['__l10n']['CSS class:'] = '';
$GLOBALS['__l10n']['You must provide a link title'] = '';
$GLOBALS['__l10n']['You must provide a link URL'] = '';
$GLOBALS['__l10n']['You need to provide a XBEL or OPML file.'] = '';
$GLOBALS['__l10n']['File is not in XML format.'] = '';
$GLOBALS['__l10n']['No such link or title'] = '';
$GLOBALS['__l10n']['Link has been successfully updated'] = '';
$GLOBALS['__l10n']['Category has been successfully updated'] = '';
$GLOBALS['__l10n']['Return to blogroll'] = '';
$GLOBALS['__l10n']['Edit category'] = '';
$GLOBALS['__l10n']['Edit link'] = '';
$GLOBALS['__l10n']['XFN information'] = '';
$GLOBALS['__l10n']['_xfn_Me'] = 'Me';
$GLOBALS['__l10n']['_xfn_Another link for myself'] = 'Another link for myself';
$GLOBALS['__l10n']['_xfn_Friendship'] = 'Friendship';
$GLOBALS['__l10n']['_xfn_Contact'] = 'Contact';
$GLOBALS['__l10n']['_xfn_Acquaintance'] = 'Acquaintance';
$GLOBALS['__l10n']['_xfn_Friend'] = 'Friend';
$GLOBALS['__l10n']['_xfn_Physical'] = 'Physical';
$GLOBALS['__l10n']['_xfn_Met'] = 'Met';
$GLOBALS['__l10n']['_xfn_Professional'] = 'Professional';
$GLOBALS['__l10n']['_xfn_Co-worker'] = 'Co-worker';
$GLOBALS['__l10n']['_xfn_Colleague'] = 'Colleague';
$GLOBALS['__l10n']['_xfn_Geographical'] = 'Geographical';
$GLOBALS['__l10n']['_xfn_Co-resident'] = 'Co-resident';
$GLOBALS['__l10n']['_xfn_Neighbor'] = 'Neighbor';
$GLOBALS['__l10n']['_xfn_Family'] = 'Family';
$GLOBALS['__l10n']['_xfn_Child'] = 'Child';
$GLOBALS['__l10n']['_xfn_Parent'] = 'Parent';
$GLOBALS['__l10n']['_xfn_Sibling'] = 'Sibling';
$GLOBALS['__l10n']['_xfn_Spouse'] = 'Spouse';
$GLOBALS['__l10n']['_xfn_Kin'] = 'Kin';
$GLOBALS['__l10n']['_xfn_Romantic'] = 'Romantic';
$GLOBALS['__l10n']['_xfn_Muse'] = 'Muse';
$GLOBALS['__l10n']['_xfn_Crush'] = 'Crush';
$GLOBALS['__l10n']['_xfn_Date'] = 'Date';
$GLOBALS['__l10n']['_xfn_Sweetheart'] = 'Sweetheart';
$GLOBALS['__l10n']['Nothing to import'] = '';
$GLOBALS['__l10n']['links have been successfully imported.'] = '';
$GLOBALS['__l10n']['Import operation cancelled.'] = '';
$GLOBALS['__l10n']['Link has been successfully created.'] = '';
$GLOBALS['__l10n']['category has been successfully created.'] = '';
$GLOBALS['__l10n']['Items have been successfully removed.'] = '';
$GLOBALS['__l10n']['Items order has been successfully updated'] = '';
$GLOBALS['__l10n']['URL'] = '';
$GLOBALS['__l10n']['Lang'] = '';
$GLOBALS['__l10n']['select this link'] = '';
$GLOBALS['__l10n']['Delete selected links'] = '';
$GLOBALS['__l10n']['Are you sure you want to delete selected links?'] = '';
$GLOBALS['__l10n']['The link list is empty.'] = '';
$GLOBALS['__l10n']['Add a new link'] = '';
$GLOBALS['__l10n']['Add a category'] = '';
$GLOBALS['__l10n']['Import links'] = '';
$GLOBALS['__l10n']['OPML or XBEL File:'] = '';
$GLOBALS['__l10n']['Import'] = '';
$GLOBALS['__l10n']['Light linear gradient'] = '';
$GLOBALS['__l10n']['Medium linear gradient'] = '';
$GLOBALS['__l10n']['Dark linear gradient'] = '';
$GLOBALS['__l10n']['Solid color'] = '';
$GLOBALS['__l10n']['Custom...'] = '';
$GLOBALS['__l10n']['Theme configuration has been successfully updated.'] = '';
$GLOBALS['__l10n']['Blowup configuration'] = '';
$GLOBALS['__l10n']['Predefined styles'] = '';
$GLOBALS['__l10n']['Apply code'] = '';
$GLOBALS['__l10n']['Choose a predefined style'] = '';
$GLOBALS['__l10n']['Back to Blog appearance'] = '';
$GLOBALS['__l10n']['For the following reasons, images cannot be created. You won\'t be able to change some background properties.'] = '';
$GLOBALS['__l10n']['Customization'] = '';
$GLOBALS['__l10n']['General'] = '';
$GLOBALS['__l10n']['Background color:'] = '';
$GLOBALS['__l10n']['Background color fill:'] = '';
$GLOBALS['__l10n']['Main text font:'] = '';
$GLOBALS['__l10n']['Main text font size:'] = '';
$GLOBALS['__l10n']['Main text color:'] = '';
$GLOBALS['__l10n']['Text line height:'] = '';
$GLOBALS['__l10n']['Links color:'] = '';
$GLOBALS['__l10n']['Visited links color:'] = '';
$GLOBALS['__l10n']['Focus links color:'] = '';
$GLOBALS['__l10n']['Page top'] = '';
$GLOBALS['__l10n']['Prelude color:'] = '';
$GLOBALS['__l10n']['Hide main title'] = '';
$GLOBALS['__l10n']['Main title font:'] = '';
$GLOBALS['__l10n']['Main title font size:'] = '';
$GLOBALS['__l10n']['Main title color:'] = '';
$GLOBALS['__l10n']['Main title alignment:'] = '';
$GLOBALS['__l10n']['center'] = '';
$GLOBALS['__l10n']['left'] = '';
$GLOBALS['__l10n']['right'] = '';
$GLOBALS['__l10n']['Main title position (x:y)'] = '';
$GLOBALS['__l10n']['Top image'] = '';
$GLOBALS['__l10n']['Choose "Custom..." to upload your own image.'] = '';
$GLOBALS['__l10n']['Add your image:'] = '';
$GLOBALS['__l10n']['JPEG or PNG file, 800 pixels wide, maximum size %s'] = '';
$GLOBALS['__l10n']['Sidebar'] = '';
$GLOBALS['__l10n']['Sidebar position:'] = '';
$GLOBALS['__l10n']['Sidebar text font:'] = '';
$GLOBALS['__l10n']['Sidebar text font size:'] = '';
$GLOBALS['__l10n']['Sidebar text color:'] = '';
$GLOBALS['__l10n']['Sidebar titles font:'] = '';
$GLOBALS['__l10n']['Sidebar titles font size:'] = '';
$GLOBALS['__l10n']['Sidebar titles color:'] = '';
$GLOBALS['__l10n']['Sidebar 2nd level titles font:'] = '';
$GLOBALS['__l10n']['Sidebar 2nd level titles font size:'] = '';
$GLOBALS['__l10n']['Sidebar 2nd level titles color:'] = '';
$GLOBALS['__l10n']['Sidebar lines color:'] = '';
$GLOBALS['__l10n']['Sidebar links color:'] = '';
$GLOBALS['__l10n']['Sidebar visited links color:'] = '';
$GLOBALS['__l10n']['Sidebar focus links color:'] = '';
$GLOBALS['__l10n']['Date title font:'] = '';
$GLOBALS['__l10n']['Date title font size:'] = '';
$GLOBALS['__l10n']['Date title color:'] = '';
$GLOBALS['__l10n']['Entry title font:'] = '';
$GLOBALS['__l10n']['Entry title font size:'] = '';
$GLOBALS['__l10n']['Entry title color:'] = '';
$GLOBALS['__l10n']['Comment background color:'] = '';
$GLOBALS['__l10n']['Comment text color:'] = '';
$GLOBALS['__l10n']['My comment background color:'] = '';
$GLOBALS['__l10n']['My comment text color:'] = '';
$GLOBALS['__l10n']['Footer'] = '';
$GLOBALS['__l10n']['Footer font:'] = '';
$GLOBALS['__l10n']['Footer font size:'] = '';
$GLOBALS['__l10n']['Footer color:'] = '';
$GLOBALS['__l10n']['Footer links color:'] = '';
$GLOBALS['__l10n']['Footer background color:'] = '';
$GLOBALS['__l10n']['Additional CSS'] = '';
$GLOBALS['__l10n']['Any additional CSS styles (must be written using the CSS syntax):'] = '';
$GLOBALS['__l10n']['Configuration import / export'] = '';
$GLOBALS['__l10n']['You can share your configuration using the following code. To apply a configuration, paste the code, click on "Apply code" and save.'] = '';
$GLOBALS['__l10n']['Copy this code:'] = '';
$GLOBALS['__l10n']['default'] = '';
$GLOBALS['__l10n']['The \'public\' directory does not exist.'] = '';
$GLOBALS['__l10n']['The \'%s\' directory cannot be modified.'] = '';
$GLOBALS['__l10n']['Unable to create css file.'] = '';
$GLOBALS['__l10n']['At least one of the following functions is not available: imagecreatetruecolor, imagepng & imagecreatefrompng.'] = '';
$GLOBALS['__l10n']['Unable to create images.'] = '';
$GLOBALS['__l10n']['Invalid file type.'] = '';
$GLOBALS['__l10n']['Uploaded image is not 800 pixels wide.'] = '';
$GLOBALS['__l10n']['Unable to open image.'] = '';
$GLOBALS['__l10n']['Checks trackback source for a link to the post'] = '';
$GLOBALS['__l10n']['Import/Export'] = '';
$GLOBALS['__l10n']['Flat file export'] = '';
$GLOBALS['__l10n']['Exports a blog or a full Dotclear installation to flat file.'] = '';
$GLOBALS['__l10n']['Export file not found.'] = '';
$GLOBALS['__l10n']['Failed to compress export file.'] = '';
$GLOBALS['__l10n']['Single blog'] = '';
$GLOBALS['__l10n']['This will create an export of your current blog: %s'] = '';
$GLOBALS['__l10n']['Compress file'] = '';
$GLOBALS['__l10n']['You may also want to download your media directory as a zip file'] = '';
$GLOBALS['__l10n']['Export'] = '';
$GLOBALS['__l10n']['Multiple blogs'] = '';
$GLOBALS['__l10n']['This will create an export of all the content of your database.'] = '';
$GLOBALS['__l10n']['Congratulation!'] = '';
$GLOBALS['__l10n']['Your blog has been successfully imported. Welcome on Dotclear 2!'] = '';
$GLOBALS['__l10n']['Why don\'t you blog this now?'] = '';
$GLOBALS['__l10n']['or'] = '';
$GLOBALS['__l10n']['visit your dashboard'] = '';
$GLOBALS['__l10n']['Dotclear 1.2 import'] = '';
$GLOBALS['__l10n']['Import a Dotclear 1.2 installation into your current blog.'] = '';
$GLOBALS['__l10n']['Import the content of a Dotclear 1.2\'s blog in the current blog: %s.'] = '';
$GLOBALS['__l10n']['Please note that this process will empty your categories, blogroll, entries and comments on the current blog.'] = '';
$GLOBALS['__l10n']['General information'] = '';
$GLOBALS['__l10n']['Import my blog now'] = '';
$GLOBALS['__l10n']['We first need some information about your old Dotclear 1.2 installation.'] = '';
$GLOBALS['__l10n']['Entries import options'] = '';
$GLOBALS['__l10n']['Number of entries to import at once:'] = '';
$GLOBALS['__l10n']['Importing users'] = '';
$GLOBALS['__l10n']['Importing categories'] = '';
$GLOBALS['__l10n']['Importing blogroll'] = '';
$GLOBALS['__l10n']['Importing entries from %d to %d / %d'] = '';
$GLOBALS['__l10n']['Please read carefully'] = '';
$GLOBALS['__l10n']['Every newly imported user has received a random password and will need to ask for a new one by following the "I forgot my password" link on the login page (Their registered email address has to be valid.)'] = '';
$GLOBALS['__l10n']['Please note that Dotclear 2 has a new URL layout. You can avoid broken links by installing <a href="%s">DC1 redirect</a> plugin and activate it in your blog configuration.'] = '';
$GLOBALS['__l10n']['next step'] = '';
$GLOBALS['__l10n']['Depending on the size of your blog, it could take a few minutes.'] = '';
$GLOBALS['__l10n']['Dotclear tables not found'] = '';
$GLOBALS['__l10n']['RSS or Atom feed import'] = '';
$GLOBALS['__l10n']['Add a feed content to the blog.'] = '';
$GLOBALS['__l10n']['Cannot retrieve feed URL.'] = '';
$GLOBALS['__l10n']['No items in feed.'] = '';
$GLOBALS['__l10n']['Content successfully imported.'] = '';
$GLOBALS['__l10n']['Add a feed content to the current blog: <strong>%s</strong>.'] = '';
$GLOBALS['__l10n']['Feed URL:'] = '';
$GLOBALS['__l10n']['Flat file import'] = '';
$GLOBALS['__l10n']['Imports a blog or a full Dotclear installation from flat file.'] = '';
$GLOBALS['__l10n']['Single blog successfully imported.'] = '';
$GLOBALS['__l10n']['Are you sure you want to import a full backup file?'] = '';
$GLOBALS['__l10n']['This will import a single blog backup as new content in the current blog: <strong>%s</strong>.'] = '';
$GLOBALS['__l10n']['Upload a backup file'] = '';
$GLOBALS['__l10n']['maximum size %s'] = '';
$GLOBALS['__l10n']['or pick up a local file in your public directory'] = '';
$GLOBALS['__l10n']['This will reset all the content of your database, except users.'] = '';
$GLOBALS['__l10n']['Another file with same name exists.'] = '';
$GLOBALS['__l10n']['Failed to extract backup file.'] = '';
$GLOBALS['__l10n']['No backup in compressed file.'] = '';
$GLOBALS['__l10n']['WordPress import'] = '';
$GLOBALS['__l10n']['Import a WordPress installation into your current blog.'] = '';
$GLOBALS['__l10n']['This will import your WordPress content as new content in the current blog: %s.'] = '';
$GLOBALS['__l10n']['We first need some information about your old WordPress installation.'] = '';
$GLOBALS['__l10n']['WordPress and Dotclear\'s handling of categories are quite different. You can assign several categories to a single post in WordPress. In the Dotclear world, we see it more like "One category, several tags." Therefore Dotclear can only import one category per post and will chose the lowest numbered one. If you want to keep a trace of every category, you can import them as tags, with an optional prefix.'] = '';
$GLOBALS['__l10n']['On the other hand, in WordPress, a post can not be uncategorized, and a default installation has a first category labelised <i>"Uncategorized"</i>.If you did not change that category, you can just ignore it while importing your blog, as Dotclear allows you to actually keep your posts uncategorized.'] = '';
$GLOBALS['__l10n']['Ignore the first category:'] = '';
$GLOBALS['__l10n']['Import lowest numbered category on posts:'] = '';
$GLOBALS['__l10n']['Import all categories as tags:'] = '';
$GLOBALS['__l10n']['Prefix such tags with:'] = '';
$GLOBALS['__l10n']['Content filters'] = '';
$GLOBALS['__l10n']['You may want to process your post and/or comment content with the following filters.'] = '';
$GLOBALS['__l10n']['Post content formatter:'] = '';
$GLOBALS['__l10n']['Comment content formatter:'] = '';
$GLOBALS['__l10n']['WordPress tables not found'] = '';
$GLOBALS['__l10n']['No file to read.'] = '';
$GLOBALS['__l10n']['File is not a DotClear backup.'] = '';
$GLOBALS['__l10n']['File is not a single blog export.'] = '';
$GLOBALS['__l10n']['File is not a full export.'] = '';
$GLOBALS['__l10n']['ID of "%3$s" does not match on record "%1$s" at line %2$s of backup file.'] = '';
$GLOBALS['__l10n']['Database export'] = '';
$GLOBALS['__l10n']['Download database of current blog'] = '';
$GLOBALS['__l10n']['Download database of all blogs'] = '';
$GLOBALS['__l10n']['Please wait...'] = '';
$GLOBALS['__l10n']['Export functions are in the page %s.'] = '';
$GLOBALS['__l10n']['Maintenance'] = '';
$GLOBALS['__l10n']['Servicing'] = '';
$GLOBALS['__l10n']['Tools to maintain the performance of your blogs.'] = '';
$GLOBALS['__l10n']['Backup'] = '';
$GLOBALS['__l10n']['Tools to back up your content.'] = '';
$GLOBALS['__l10n']['Development'] = '';
$GLOBALS['__l10n']['Tools to assist in development of plugins, themes and core.'] = '';
$GLOBALS['__l10n']['Optimize'] = '';
$GLOBALS['__l10n']['Count and index'] = '';
$GLOBALS['__l10n']['Purge'] = '';
$GLOBALS['__l10n']['Other'] = '';
$GLOBALS['__l10n']['Current blog'] = '';
$GLOBALS['__l10n']['All blogs'] = '';
$GLOBALS['__l10n']['Maintain translations'] = '';
$GLOBALS['__l10n']['Translations'] = '';
$GLOBALS['__l10n']['One task to execute'][0] = '';
$GLOBALS['__l10n']['One task to execute'][1] = '';
$GLOBALS['__l10n']['This task has never been executed.'] = '';
$GLOBALS['__l10n']['Last execution of this task was on %s.'] = '';
$GLOBALS['__l10n']['There is a task to execute.'][0] = '';
$GLOBALS['__l10n']['There is a task to execute.'][1] = '';
$GLOBALS['__l10n']['Manage tasks'] = '';
$GLOBALS['__l10n']['Display overdue tasks counter on maintenance dashboard icon'] = '';
$GLOBALS['__l10n']['Display overdue tasks list on dashboard items'] = '';
$GLOBALS['__l10n']['Failed to execute task.'] = '';
$GLOBALS['__l10n']['Task successfully executed.'] = '';
$GLOBALS['__l10n']['Empty templates cache directory'] = '';
$GLOBALS['__l10n']['Templates cache directory emptied.'] = '';
$GLOBALS['__l10n']['Failed to empty templates cache directory.'] = '';
$GLOBALS['__l10n']['It may be useful to empty this cache when modifying a theme\'s .html or .css files (or when updating a theme or plugin). Notice : with some hosters, the templates cache cannot be emptied with this plugin. You may then have to delete the directory <strong>/cbtpl/</strong> directly on the server with your FTP software.'] = '';
$GLOBALS['__l10n']['Count again comments and trackbacks'] = '';
$GLOBALS['__l10n']['Comments and trackback counted.'] = '';
$GLOBALS['__l10n']['Failed to count comments and trackbacks.'] = '';
$GLOBALS['__l10n']['Count again comments and trackbacks allows to check their exact numbers. This operation can be useful when importing from another blog platform (or when migrating from dotclear 1 to dotclear 2).'] = '';
$GLOBALS['__l10n']['Search engine index'] = '';
$GLOBALS['__l10n']['Index all comments for search engine'] = '';
$GLOBALS['__l10n']['Next'] = '';
$GLOBALS['__l10n']['Indexing comment %d to %d.'] = '';
$GLOBALS['__l10n']['Comments index done.'] = '';
$GLOBALS['__l10n']['Failed to index comments.'] = '';
$GLOBALS['__l10n']['Index all comments and trackbacks in search engine index. This operation is necessary, after importing content in your blog, to use internal search engine, on public and private pages.'] = '';
$GLOBALS['__l10n']['Index all entries for search engine'] = '';
$GLOBALS['__l10n']['Indexing entry %d to %d.'] = '';
$GLOBALS['__l10n']['Entries index done.'] = '';
$GLOBALS['__l10n']['Failed to index entries.'] = '';
$GLOBALS['__l10n']['Index all entries in search engine index. This operation is necessary, after importing content in your blog, to use internal search engine, on public and private pages.'] = '';
$GLOBALS['__l10n']['Delete all logs'] = '';
$GLOBALS['__l10n']['Logs deleted.'] = '';
$GLOBALS['__l10n']['Failed to delete logs.'] = '';
$GLOBALS['__l10n']['Logs record all activity and connection to your blog history. Unless you need to keep this history, consider deleting these logs from time to time.'] = '';
$GLOBALS['__l10n']['Entries metadata'] = '';
$GLOBALS['__l10n']['Synchronize entries metadata'] = '';
$GLOBALS['__l10n']['Synchronize entry %d to %d.'] = '';
$GLOBALS['__l10n']['Entries metadata synchronize done.'] = '';
$GLOBALS['__l10n']['Failed to synchronize entries metadata.'] = '';
$GLOBALS['__l10n']['Synchronize all entries metadata could be useful after importing content in your blog or do bad operation on database tables.'] = '';
$GLOBALS['__l10n']['Optimise database'] = '';
$GLOBALS['__l10n']['optimize tables'] = '';
$GLOBALS['__l10n']['Optimization successful.'] = '';
$GLOBALS['__l10n']['Failed to optimize tables.'] = '';
$GLOBALS['__l10n']['After numerous delete or update operations on Dotclear\'s database, it gets fragmented. Optimizing will allow to defragment it. It has no incidence on your data\'s integrity. It is recommended to optimize before any blog export.'] = '';
$GLOBALS['__l10n']['Download media folder of current blog'] = '';
$GLOBALS['__l10n']['It may be useful to backup your media folder. This compress all content of media folder into a single zip file. Notice : with some hosters, the media folder cannot be compressed with this plugin if it is too big.'] = '';
$GLOBALS['__l10n']['Download active theme of current blog'] = '';
$GLOBALS['__l10n']['It may be useful to backup the active theme before any change or update. This compress theme folder into a single zip file.'] = '';
$GLOBALS['__l10n']['Maintenance plugin has been successfully configured.'] = '';
$GLOBALS['__l10n']['Never'] = '';
$GLOBALS['__l10n']['Every week'] = '';
$GLOBALS['__l10n']['Every two weeks'] = '';
$GLOBALS['__l10n']['Every month'] = '';
$GLOBALS['__l10n']['Every two months'] = '';
$GLOBALS['__l10n']['You have not sufficient permissions to view this page.'] = '';
$GLOBALS['__l10n']['You should execute it now.'] = '';
$GLOBALS['__l10n']['Execute task'] = '';
$GLOBALS['__l10n']['This may take a very long time.'] = '';
$GLOBALS['__l10n']['Alert settings'] = '';
$GLOBALS['__l10n']['Activation'] = '';
$GLOBALS['__l10n']['Display alert messages on late tasks'] = '';
$GLOBALS['__l10n']['You can place list of late tasks on your %s.'] = '';
$GLOBALS['__l10n']['Frequency'] = '';
$GLOBALS['__l10n']['Use one recall time for all tasks'] = '';
$GLOBALS['__l10n']['Recall time for all tasks:'] = '';
$GLOBALS['__l10n']['Use one recall time per task'] = '';
$GLOBALS['__l10n']['New page'] = '';
$GLOBALS['__l10n']['%d page'] = '';
$GLOBALS['__l10n']['%d pages'] = '';
$GLOBALS['__l10n']['manage pages'] = '';
$GLOBALS['__l10n']['My first page'] = '';
$GLOBALS['__l10n']['This is your first page. When you\'re ready to blog, log in to edit or delete it.'] = '';
$GLOBALS['__l10n']['Published on'] = '';
$GLOBALS['__l10n']['This page\'s comments feed'] = '';
$GLOBALS['__l10n']['You must provide a valid email address.'] = '';
$GLOBALS['__l10n']['Page title'] = '';
$GLOBALS['__l10n']['Page position'] = '';
$GLOBALS['__l10n']['Publication date'] = '';
$GLOBALS['__l10n']['Pages actions'] = '';
$GLOBALS['__l10n']['Back to pages list'] = '';
$GLOBALS['__l10n']['Selected pages have been successfully reordered.'] = '';
$GLOBALS['__l10n']['No page'] = '';
$GLOBALS['__l10n']['Hidden'] = '';
$GLOBALS['__l10n']['Select this page'] = '';
$GLOBALS['__l10n']['Are you sure you want to delete selected pages?'] = '';
$GLOBALS['__l10n']['Selected pages have been successfully updated.'] = '';
$GLOBALS['__l10n']['Selected pages have been successfully deleted.'] = '';
$GLOBALS['__l10n']['Selected pages action:'] = '';
$GLOBALS['__l10n']['To rearrange pages order, change number at the begining of the line, then click on “Save pages order” button.'] = '';
$GLOBALS['__l10n']['To rearrange pages order, move items by drag and drop, then click on “Save pages order” button.'] = '';
$GLOBALS['__l10n']['Save pages order'] = '';
$GLOBALS['__l10n']['This page does not exist.'] = '';
$GLOBALS['__l10n']['Edit page'] = '';
$GLOBALS['__l10n']['Are you sure you want to delete this page?'] = '';
$GLOBALS['__l10n']['Page has been successfully updated.'] = '';
$GLOBALS['__l10n']['Page has been successfully created.'] = '';
$GLOBALS['__l10n']['Go to this page on the site'] = '';
$GLOBALS['__l10n']['Page status'] = '';
$GLOBALS['__l10n']['Page language'] = '';
$GLOBALS['__l10n']['Hide in widget Pages'] = '';
$GLOBALS['__l10n']['Warning: If you set the URL manually, it may conflict with another page.'] = '';
$GLOBALS['__l10n']['Introduction to the page.'] = '';
$GLOBALS['__l10n']['Select this comment'] = '';
$GLOBALS['__l10n']['Pings'] = '';
$GLOBALS['__l10n']['Settings have been successfully updated.'] = '';
$GLOBALS['__l10n']['Pings configuration'] = '';
$GLOBALS['__l10n']['Activate pings extension'] = '';
$GLOBALS['__l10n']['Service name:'] = '';
$GLOBALS['__l10n']['Service URI:'] = '';
$GLOBALS['__l10n']['Error'] = '';
$GLOBALS['__l10n']['Test ping services'] = '';
$GLOBALS['__l10n']['Check all'] = '';
$GLOBALS['__l10n']['Simple menu'] = '';
$GLOBALS['__l10n']['All months'] = '';
$GLOBALS['__l10n']['All tags'] = '';
$GLOBALS['__l10n']['Home'] = '';
$GLOBALS['__l10n']['Archive'] = '';
$GLOBALS['__l10n']['Page'] = '';
$GLOBALS['__l10n']['Tags'] = '';
$GLOBALS['__l10n']['User defined'] = '';
$GLOBALS['__l10n']['Label'] = '';
$GLOBALS['__l10n']['Recent posts'] = '';
$GLOBALS['__l10n']['Switch to %s language'] = '';
$GLOBALS['__l10n']['Recent Posts from this category'] = '';
$GLOBALS['__l10n']['Archives'] = '';
$GLOBALS['__l10n']['Posts from %s'] = '';
$GLOBALS['__l10n']['Recent posts for %s tag'] = '';
$GLOBALS['__l10n']['Menu item has been successfully added.'] = '';
$GLOBALS['__l10n']['Label and URL of menu item are mandatory.'] = '';
$GLOBALS['__l10n']['Menu items have been successfully removed.'] = '';
$GLOBALS['__l10n']['No menu items selected.'] = '';
$GLOBALS['__l10n']['Label is mandatory.'] = '';
$GLOBALS['__l10n']['URL is mandatory.'] = '';
$GLOBALS['__l10n']['Menu items have been successfully updated.'] = '';
$GLOBALS['__l10n']['Step #1'] = '';
$GLOBALS['__l10n']['Step #2'] = '';
$GLOBALS['__l10n']['Step #3'] = '';
$GLOBALS['__l10n']['Add item'] = '';
$GLOBALS['__l10n']['Select type'] = '';
$GLOBALS['__l10n']['Type of item menu:'] = '';
$GLOBALS['__l10n']['Continue...'] = 'Continue…';
$GLOBALS['__l10n']['Select language:'] = '';
$GLOBALS['__l10n']['Select category:'] = '';
$GLOBALS['__l10n']['Select month (if necessary):'] = '';
$GLOBALS['__l10n']['Select page:'] = '';
$GLOBALS['__l10n']['Select tag (if necessary):'] = '';
$GLOBALS['__l10n']['Label of item menu:'] = '';
$GLOBALS['__l10n']['Description of item menu:'] = '';
$GLOBALS['__l10n']['URL of item menu:'] = '';
$GLOBALS['__l10n']['Add this item'] = '';
$GLOBALS['__l10n']['Add an item'] = '';
$GLOBALS['__l10n']['Menu items list'] = '';
$GLOBALS['__l10n']['Update menu'] = '';
$GLOBALS['__l10n']['Delete selected menu items'] = '';
$GLOBALS['__l10n']['Are you sure you want to remove selected menu items?'] = '';
$GLOBALS['__l10n']['No menu items so far.'] = '';
$GLOBALS['__l10n']['Add tags'] = '';
$GLOBALS['__l10n']['Remove tags'] = '';
$GLOBALS['__l10n']['Tag has been successfully added to selected entries'][0] = '';
$GLOBALS['__l10n']['Tag has been successfully added to selected entries'][1] = '';
$GLOBALS['__l10n']['Add tags to this selection'] = '';
$GLOBALS['__l10n']['Are you sure you want to remove this %s?'] = '';
$GLOBALS['__l10n']['Add a %s to this entry'] = '';
$GLOBALS['__l10n']['Choose from list'] = '';
$GLOBALS['__l10n']['all'] = '';
$GLOBALS['__l10n']['Enter tags separated by coma'] = '';
$GLOBALS['__l10n']['used in %e - frequency %p%'] = '';
$GLOBALS['__l10n']['entry'] = '';
$GLOBALS['__l10n']['entries'] = '';
$GLOBALS['__l10n']['Tags to add:'] = '';
$GLOBALS['__l10n']['Tag has been successfully removed from selected entries'][0] = '';
$GLOBALS['__l10n']['Tag has been successfully removed from selected entries'][1] = '';
$GLOBALS['__l10n']['No tags for selected entries'] = '';
$GLOBALS['__l10n']['Remove selected tags from this selection'] = '';
$GLOBALS['__l10n']['Following tags have been found in selected entries:'] = '';
$GLOBALS['__l10n']['Tag'] = '';
$GLOBALS['__l10n']['Short'] = '';
$GLOBALS['__l10n']['Extended'] = '';
$GLOBALS['__l10n']['Tags list format:'] = '';
$GLOBALS['__l10n']['This tag\'s comments Atom feed'] = '';
$GLOBALS['__l10n']['This tag\'s entries Atom feed'] = '';
$GLOBALS['__l10n']['Limit (empty means no limit):'] = '';
$GLOBALS['__l10n']['Entries count'] = '';
$GLOBALS['__l10n']['Tag name'] = '';
$GLOBALS['__l10n']['Link to all tags:'] = '';
$GLOBALS['__l10n']['Tag has been successfully renamed'] = '';
$GLOBALS['__l10n']['Tag has been successfully removed'] = '';
$GLOBALS['__l10n']['Are you sure you want to remove tag: “%s”?'] = '';
$GLOBALS['__l10n']['Back to tags list'] = '';
$GLOBALS['__l10n']['Rename'] = '';
$GLOBALS['__l10n']['Delete this tag'] = '';
$GLOBALS['__l10n']['List of entries with the tag “%s”'] = '';
$GLOBALS['__l10n']['No tags on this blog.'] = '';
$GLOBALS['__l10n']['Edit theme files'] = '';
$GLOBALS['__l10n']['Syntax highlighting in theme editor'] = '';
$GLOBALS['__l10n']['No file'] = '';
$GLOBALS['__l10n']['File does not exist.'] = '';
$GLOBALS['__l10n']['File %s is not readable'] = '';
$GLOBALS['__l10n']['Unable to write file %s. Please check your theme files and folders permissions.'] = '';
$GLOBALS['__l10n']['Saving document...'] = '';
$GLOBALS['__l10n']['Document saved'] = '';
$GLOBALS['__l10n']['An error occurred:'] = '';
$GLOBALS['__l10n']['Your current theme on this blog is "%s".'] = '';
$GLOBALS['__l10n']['You can\'t edit default theme.'] = '';
$GLOBALS['__l10n']['Please select a file to edit.'] = '';
$GLOBALS['__l10n']['File editor'] = '';
$GLOBALS['__l10n']['Editing file %s'] = '';
$GLOBALS['__l10n']['This file is not writable. Please check your theme files permissions.'] = '';
$GLOBALS['__l10n']['Templates files'] = '';
$GLOBALS['__l10n']['CSS files'] = '';
$GLOBALS['__l10n']['JavaScript files'] = '';
$GLOBALS['__l10n']['Locales files'] = '';
$GLOBALS['__l10n']['Preferences successfully updated'] = '';
$GLOBALS['__l10n']['user:preferences'] = '';
$GLOBALS['__l10n']['User preferences'] = '';
$GLOBALS['__l10n']['Global preferences'] = '';
$GLOBALS['__l10n']['Presentation widgets'] = '';
$GLOBALS['__l10n']['Search engine'] = '';
$GLOBALS['__l10n']['Navigation links'] = '';
$GLOBALS['__l10n']['Selected entries'] = '';
$GLOBALS['__l10n']['Best of me'] = '';
$GLOBALS['__l10n']['Blog languages'] = '';
$GLOBALS['__l10n']['With entries counts'] = '';
$GLOBALS['__l10n']['Include sub cats in count'] = '';
$GLOBALS['__l10n']['Include empty categories'] = '';
$GLOBALS['__l10n']['Subscribe links'] = '';
$GLOBALS['__l10n']['Subscribe'] = '';
$GLOBALS['__l10n']['Feeds type:'] = '';
$GLOBALS['__l10n']['Feed reader'] = '';
$GLOBALS['__l10n']['Somewhere else'] = '';
$GLOBALS['__l10n']['Entries limit:'] = '';
$GLOBALS['__l10n']['Text'] = '';
$GLOBALS['__l10n']['Text:'] = '';
$GLOBALS['__l10n']['Last entries'] = '';
$GLOBALS['__l10n']['Uncategorized'] = '';
$GLOBALS['__l10n']['Tag:'] = '';
$GLOBALS['__l10n']['Last comments'] = '';
$GLOBALS['__l10n']['Comments limit:'] = '';
$GLOBALS['__l10n']['This blog\'s entries %s feed'] = '';
$GLOBALS['__l10n']['This blog\'s comments %s feed'] = '';
$GLOBALS['__l10n']['Entries feed'] = '';
$GLOBALS['__l10n']['Comments feed'] = '';
$GLOBALS['__l10n']['navigation'] = '';
$GLOBALS['__l10n']['extra'] = '';
$GLOBALS['__l10n']['custom'] = '';
$GLOBALS['__l10n']['empty string'] = '';
$GLOBALS['__l10n']['Widgets'] = '';
$GLOBALS['__l10n']['Are you sure you want to reset sidebars?'] = '';
$GLOBALS['__l10n']['Available widgets'] = '';
$GLOBALS['__l10n']['Drag widgets from this list to one of the sidebars, for add.'] = '';
$GLOBALS['__l10n']['order'] = '';
$GLOBALS['__l10n']['Append to:'] = '';
$GLOBALS['__l10n']['Add widgets to sidebars'] = '';
$GLOBALS['__l10n']['Navigation sidebar'] = '';
$GLOBALS['__l10n']['Extra sidebar'] = '';
$GLOBALS['__l10n']['Custom sidebar'] = '';
$GLOBALS['__l10n']['Update sidebars'] = '';
$GLOBALS['__l10n']['Reset sidebars'] = '';
$GLOBALS['__l10n']['Widget ID:'] = '';
$GLOBALS['__l10n']['No setting for this widget'] = '';
$GLOBALS['__l10n']['boolean'] = '';
$GLOBALS['__l10n']['possible values:'] = '';
$GLOBALS['__l10n']['listitem'] = '';
$GLOBALS['__l10n']['string'] = '';
$GLOBALS['__l10n']['Setting name:'] = '';
$GLOBALS['__l10n']['No widget as far.'] = '';
$GLOBALS['__l10n']['Up the widget'] = '';
$GLOBALS['__l10n']['Down the widget'] = '';
$GLOBALS['__l10n']['Remove widget'] = '';
$GLOBALS['__l10n']['Drag widgets here to remove.'] = '';
